mpl-tools
========

[![image](https://travis-ci.org/patricknraanes/mpl-tools.svg?branch=master)](https://travis-ci.org/patricknraanes/mpl-tools)
[![image](https://coveralls.io/repos/github/patricknraanes/mpl-tools/badge.svg?branch=master)](https://coveralls.io/github/patricknraanes/mpl-tools?branch=master)
[![image](http://hits.dwyl.com/patricknraanes/mpl-tools.svg)](http://hits.dwyl.com/patricknraanes/mpl-tools)
[![image](https://badge.fury.io/py/mpl-tools.svg)](https://badge.fury.io/py/mpl-tools)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mpl-tools)](https://pypi.org/project/mpl-tools/0.1.5/)
<!--[![image](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)-->

This package provides some tools to work with
[Matplotlib](https://matplotlib.org/).

[Read the docs](https://mpl-tools.readthedocs.io/en/latest/)
[![Documentation Status](https://readthedocs.org/projects/mpl-tools/badge/?version=latest)](https://mpl-tools.readthedocs.io/en/latest/?badge=latest)

Contents
--------

-   `freshfig`
-   `anchor_axes`, with auxiliaries:
    -   `align_ax_with`
    -   `set_ax_size`
    -   `get_legend_bbox`
    -   `xFontsize`
-   `add_log_toggler`
    -   `toggle_scale`
